SyncupAction

Enum SyncupAction 

pub enum SyncupAction {
    RolledBack {
        matchpoint_vlsn: u64,
        start_vlsn: u64,
    },
    NeedsRestore,
}
A replicated database environment.

This is the entry point for replication. It wraps a standard Environment and adds replication capabilities including master election, replica streaming, and commit acknowledgments.

High Availability (HA) provides a replicated, embedded database management system which provides fast, reliable, and scalable data management. HA enables replication of an environment across a Replication Group. A ReplicatedEnvironment is a single node in the replication group.

ReplicatedEnvironment wraps a standard Environment. All database operations are executed in the same fashion in both replicated and non-replicated applications. A ReplicatedEnvironment must be transactional. All replicated databases created in the replicated environment must be transactional as well.

A ReplicatedEnvironment joins its replication group when it is created. When new() returns, the node will have established contact with the other members of the group and will be ready to service operations.

Replicated environments can be created with node type Electable or Secondary. Electable nodes can be masters or replicas, and participate in both master elections and commit durability decisions. Secondary nodes can only be replicas, not masters, and do not participate in either elections or durability decisions.

Example

use noxu_rep::{ReplicatedEnvironment, RepConfig};

let config = RepConfig::builder("my_group", "node1", "localhost")
    .node_port(5001)
    .build();
let rep_env = ReplicatedEnvironment::new(config).unwrap();

Outcome of ReplicatedEnvironment::syncup_with_feeder — the action taken by a live diverged-tail syncup. Port of the branch in JE ReplicaFeederSyncup.execute between a soft rollback and a network restore.

Variants



RolledBack

The divergent tail was rolled back to the matchpoint; resume streaming from start_vlsn (matchpoint + 1). matchpoint_vlsn == last VLSN means the replica was not diverged and nothing was truncated.

Fields

matchpoint_vlsn: u64
start_vlsn: u64


NeedsRestore

No safe rollback (no common matchpoint, or it would cross a committed txn); the replica must do a full network restore.