NodeState

Enum NodeState 

pub enum NodeState {
    Detached,
    Unknown,
    Master,
    Replica,
    Shutdown,
}
The possible states of a replication node.

These states determine which operations are permitted on the node. For example, only the Master node can execute write operations.

Variants



Detached

Node is not associated with the group. Its handle has been closed. No operations can be performed on the environment when it is in this state.



Unknown

Node is not currently in contact with the master, but is actively trying to establish contact with, or decide upon, a master. While in this state the node is restricted to performing just read operations on its environment. In a functioning group, this state is transitory.



Master

Node is the unique master of the group and can both read and write to its environment. When the node transitions to this state, the application running on the node must make provisions to start processing application level write requests in addition to read requests.



Replica

Node is a replica that is being updated by the master. It is restricted to reading its environment. When the node transitions to this state, the application running on the node must arrange for all write requests to be routed to the master.



Shutdown

Node is shutting down. No operations can be performed.

Implementations

Source

impl NodeState

pub fn is_writable(&self) -> bool

Whether this state accepts write operations.

pub fn is_readable(&self) -> bool

Whether this state accepts read operations.

pub fn is_active(&self) -> bool

Whether this state is active (participating in group).

pub fn is_master(&self) -> bool

Whether this is the Master state.

pub fn is_replica(&self) -> bool

Whether this is the Replica state.

pub fn is_detached(&self) -> bool

Whether this is the Detached state.

pub fn is_unknown(&self) -> bool

Whether this is the Unknown state.

pub fn can_transition_to(&self, new_state: NodeState) -> bool

Check if a transition to the given state is valid from this state.