pub trait LogScanner: Send {
// Required method
fn next_entry(&mut self, from_vlsn: u64) -> Option<(u64, u8, Vec<u8>)>;
}Expand description
An iterator over log entries starting from a given VLSN.
Corresponds to FeederSource / MasterFeederSource. The scanner
returns (vlsn, entry_type, payload) tuples in VLSN order. Returning
None signals that there are no more entries yet; the caller will call
next_entry again after a short wait.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".